##
# Common 是公共模块。

module Wechat::ShakeAround::Common

  # http://mp.weixin.qq.com/wiki/5/fe90761a540f6fe056c774ab3df8afe9.html
  ERROR_CODES =
    {
      -1      => '系统繁忙，此时请开发者稍候再试',
      0       => '请求成功',
      9001001 => 'POST数据参数不合法',
      9001002 => '远端服务不可用',
      9001003 => 'Ticket不合法',
      9001004 => '获取摇周边用户信息失败',
      9001005 => '获取商户信息失败',
      9001006 => '获取OpenID失败',
      9001007 => '上传文件缺失',
      9001008 => '上传素材的文件类型不合法',
      9001009 => '上传素材的文件尺寸不合法',
      9001010 => '上传失败',
      9001020 => '帐号不合法',
      9001022 => '设备申请数不合法，必须为大于0的数字',
      9001023 => '已存在审核中的设备ID申请',
      9001024 => '一次查询设备ID数量不能超过50',
      9001025 => '设备ID不合法',
      9001026 => '页面ID不合法',
      9001027 => '页面参数不合法',
      9001028 => '一次删除页面ID数量不能超过10',
      9001029 => '页面已应用在设备中，请先解除应用关系再删除',
      9001030 => '一次查询页面ID数量不能超过50',
      9001031 => '时间区间不合法',
      9001032 => '保存设备与页面的绑定关系参数错误',
      9001033 => '门店ID不合法',
      9001034 => '设备备注信息过长',
      9001035 => '设备申请参数不合法',
      9001036 => '查询起始值begin不合法',
      9001037 => '单个设备绑定页面不能超过30个',
      9001038 => '设备总数超过了限额',
      9001039 => '不合法的联系人名字',
      9001040 => '不合法的联系人电话',
      9001041 => '不合法的联系人邮箱',
      9001042 => '不合法的行业id',
      9001043 => '不合法的资质证明文件url，文件需通过“素材管理”接口上传',
      9001044 => '缺少资质证明文件',
      9001045 => '申请理由不能超过500字',
      9001046 => '公众账号未认证',
      9001047 => '不合法的设备申请批次id',
      9001048 => '审核状态为审核中或审核已通过，不能再提交申请请求',
      9001049 => '获取分组元数据失败',
      9001050 => '账号下分组数达到上限，最多为100个',
      9001051 => '分组包含的设备数达到上限，最多为10000个',
      9001052 => '每次添加到分组的设备数达到上限，每次最多操作1000个设备',
      9001053 => '每次从分组删除的设备数达到上限，每次最多操作1000个设备',
      9001054 => '待删除的分组仍存在设备',
      9001055 => '分组名称过长，上限为100个字符',
      9001056 => '分组待添加或删除的设备列表中包含有不属于该分组的设备id',
      9001057 => '分组相关信息操作失败',
      9001058 => '分组id不存在',
      9001059 => '模板页面logo_url为空',
      9001060 => '创建红包活动失败',
      9001061 => '获得红包活动ID失败',
      9001062 => '创建模板页面失败',
      9001063 => '红包提供商户公众号ID和红包发放商户公众号ID不一致',
      9001064 => '红包权限审核失败',
      9001065 => '红包权限正在审核',
      9001066 => '红包权限被取消',
      9001067 => '没有红包权限',
      9001068 => '红包活动时间不在红包权限有效时间内',
      9001069 => '设置红包活动开关失败',
      9001070 => '获得红包活动信息失败',
      9001071 => '查询红包ticket失败',
      9001072 => '红包ticket数量超过限制',
      9001073 => 'sponsor_appid与预下单时的wxappid不一致',
      9001074 => '获得红包发送ID失败',
      9001075 => '录入活动的红包总数超过创建活动时预设的total',
      9001076 => '添加红包发送ID失败',
      9001077 => '解码红包发送ID失败',
      9001078 => '获取公众号uin失败',
      9001079 => '接口调用appid与调用创建活动接口的appid不一致',
      9001090 => '录入的所有ticket都是无效ticket，可能原因为ticket重复使用，过期或金额不在1-1000元之间',
      9001091 => '活动已过期'
    }.freeze

  ##
  # 将日期文本或者日期对象转换为秒数。如：
  # Wechat::ShakeAround::Common.normalize_date '2000-01-01'
  # 或者
  # Wechat::ShakeAround::Common.normalize_date Date.today
  def normalize_date(date)
    date = Date.parse date if date.is_a? String
    date.to_time.to_i
  end

  ##
  # 将 device_id 转换为 Hash 格式。如：
  # Wechat::ShakeAround::Common.normalize_device_id '1234' # { device_id: '1234' }
  # 或者
  # Wechat::ShakeAround::Common.normalize_device_id { uuid: 'c1de0c84-5997-40ea-b3cc-c102ead33483', major: 123, minor: 456 }
  # # { uuid: 'c1de0c84-5997-40ea-b3cc-c102ead33483', major: 123, minor: 456 }
  def normalize_device_id(device_id)
    device_id.is_a?(Hash) ? device_id : { device_id: device_id.to_i }
  end

  def normalize_page_ids(page_ids)
    page_ids.is_a?(Array) ? page_ids.map { |i| i.to_i } : [ page_ids.to_i ]
  end

end
